@@ -1,6 +1,7 @@
 # __init__.py
 from atk_common.enums.api_error_type_enum import ApiErrorType
 from atk_common.enums.command_status_enum import CommandStatusType
+from atk_common.enums.detection_status_enum import DetectionStatus
 from atk_common.enums.encryption_type_enum import EncryptionType
 from atk_common.enums.image_encoding_type_enum import ImageEncodingType
 from atk_common.enums.image_part_category import ImagePartCategory
@@ -15,6 +16,7 @@ from atk_common.enums.violation_type_enum import ViolationType
 __all__ = [
     'ApiErrorType',
     'CommandStatusType',
+    'DetectionStatus',
     'EncryptionType',
     'ImageEncodingType',
     'ImagePartCategory',
